@@ -1,4 +1,4 @@
-#' Re-build outdated vignettes.
+#' Re-build outdated vignettes
 #'
 #' This rebuilds outdated vignettes with [tools::buildVignette].
 #' By default, it will rebuild all vignettes if the source file is newer than
@@ -11,7 +11,6 @@
 #' your package, add `--no-build-vignettes` to the "Build Source Package"
 #' field in your project options.
 #'
-#' @family roclets
 #' @export
 vignette_roclet <- function() {
   roclet("vignette")
@@ -43,7 +42,7 @@ vign_outdated <- function(vign) {
 vign_update <- function(vign) {
   if (!vign_outdated(vign)) return(FALSE)
 
-  message("Rebuilding ", basename(vign))
+  cli::cli_inform("Rebuilding {.file {basename(vign)}}")
   output <- tools::buildVignette(vign, dirname(vign), tangle = FALSE,
     clean = FALSE)
 
@@ -55,7 +54,7 @@ vign_update_all <- function(pkg_path) {
   if (!file.exists(vig_path)) return()
 
   if (file.exists(file.path(vig_path, "Makefile"))) {
-    message("Updating vignettes with make")
+    cli::cli_inform("Updating vignettes with make")
 
     make <- Sys.getenv("MAKE", "make")
     old <- setwd(vig_path)
@@ -63,7 +62,7 @@ vign_update_all <- function(pkg_path) {
 
     system(make)
   } else {
-    message("Updating vignettes")
+    cli::cli_inform("Updating vignettes")
 
     vigs <- tools::pkgVignettes(dir = pkg_path)
     invisible(map_lgl(vigs$docs, vign_update))
