@@ -13,8 +13,25 @@ test_that("generic keys produce expected output", {
   expect_equal(out$get_value("author"), "test")
 })
 
-# format ------------------------------------------------------------------
 
+test_that("author duplicated get removed", {
+  out <- roc_proc_text(rd_roclet(), "
+    #' @name a
+    #' @title a
+    #' @author A
+    NULL
+
+    #' @name b
+    #' @rdname a
+    #' @author A
+    NULL
+
+    #' @name c
+    #' @rdname a
+    #' @author B
+    NULL")[[1]]
+  expect_equal(out$get_value("author"), c("A", "B"))
+})
 
 test_that("@format overrides defaults", {
   out <- roc_proc_text(rd_roclet(), "
@@ -32,7 +49,6 @@ test_that("@format NULL suppresses default usage", {
     #' Title
     #'
     #' @format NULL
-    #'
     x <- list(a = 1, b = 2)")[[1]]
 
   expect_equal(out$get_value("format"), NULL)
@@ -42,10 +58,19 @@ test_that("@format not escaped", {
   out <- roc_proc_text(rd_roclet(), "
     #' Title
     #' @format %
-    #'
     x <- list(a = 1, b = 2)")[[1]]
 
   expect_equal(out$get_value("format"), "%")
-  expect_equal(out$get_rd("format"), "\\format{%}")
+  expect_equal(out$get_rd("format"), "\\format{\n%\n}")
 })
 
+
+test_that("@title warns about multiple paragraphs", {
+  block <- "
+    #' @title Paragraph 1
+    #'
+    #' Paragraph 2
+    x <- list(a = 1, b = 2)
+  "
+  expect_snapshot_warning(roc_proc_text(rd_roclet(), block))
+})
